version

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = ""

Version is set at release build time via -ldflags -X.

Functions

func String

func String() string

String resolves the version to report: the ldflags-injected value when built for a release, otherwise the module version from build info (set to a clean tag when the binary is produced by `go install <module>@vX.Y.Z`), otherwise "dev" for plain source builds.

Types

This section is empty.

Jump to